<?php
/**
 * NHLEvent is a concrete implementation of {@see MythEvent}. 
 *
 * @version $Id: NHLEvent.php,v 1.3.2.1 2006/11/05 23:06:57 dbattams Exp $
 * @author Derek Battams <derek@battams.ca>
 * @package MRE
 * @copyright 2006 GPL v2
 */

/**#@+
 * Required include
 */
require_once(APP_ROOT . '/class/MythEvent.php');
/**#@-*/

/**
 * NHLEvent monitors NHL games via ESPN.com
 *
 * NHLEvent will monitor the status of NHL games via the information provided
 * by ESPN.com.
 *
 * @package MRE
 */
class NHLEvent extends MythEvent
{
   /**
    * URL to grab game info from
    */
   const url = 'http://scores.espn.go.com/nhl/scoreboard';

   /**
    * Class constructor.
    *
    * @param string A string describing the game to be monitored
    */
   public function __construct($gameInfo)
   {
      parent::__construct();

      $criteria = $this->generateSearchTerms($gameInfo);
      if(!sizeof($criteria))
         trigger_error("Unable to generate valid search terms! [$gameInfo]", E_USER_WARNING);
      else
      {
         $data = file(self::url);
         if($data !== FALSE)
            foreach($criteria as $term)
            {
               $status = '';
               foreach($data as $line)
                  if(preg_match('/' . preg_quote($term) . '/', $line))
                  {
                     $status = $line;
                     break;
                  }
               if(preg_match('/id.*st"\>(.*)\<\/td/U', $status, $match))
               {
                  $this->setStatus($match[1]);
                  if(preg_match('/^Final/', $match[1]))
                     $this->setEventOver(TRUE);
                  else
                     $this->setEventOver(FALSE);
                  $this->setValid(TRUE);
                  break;
               }
            }
      }
      if(!$this->isValid())
         trigger_error("Unable to find NHL info for '$gameInfo'!  The NHL parser may need to be updated.", E_USER_WARNING);
   }
}

?>
